=== modified file 'drizzled/lex_string.h'
--- drizzled/lex_string.h	2011-10-14 07:28:20 +0000
+++ drizzled/lex_string.h	2011-10-14 09:23:40 +0000
@@ -47,17 +47,17 @@
 
   size_t size() const
   {
-    return length;
+    return length_;
   }
 
   void assign(const char* d, size_t s)
   {
     str= const_cast<char*>(d);
-    length = s;
+    length_ = s;
   }
 
   char* str;
-  size_t length;
+  size_t length_;
 };
 
 inline const lex_string_t &null_lex_string()

=== modified file 'drizzled/sql_lex.cc'
--- drizzled/sql_lex.cc	2011-10-10 17:33:19 +0000
+++ drizzled/sql_lex.cc	2011-10-14 09:23:40 +0000
@@ -294,14 +294,12 @@
 /* make a copy of token before ptr and set yytoklen */
 static lex_string_t get_token(Lex_input_stream *lip, uint32_t skip, uint32_t length)
 {
+  lip->yyUnget();                       // ptr points now after last token char
+  lip->yytoklen= length;
   lex_string_t tmp;
-  lip->yyUnget();                       // ptr points now after last token char
-  tmp.str= lip->m_session->mem.strdup(lip->get_tok_start() + skip, length);
-  tmp.length= lip->yytoklen= length;
-
+  tmp.assign(lip->m_session->mem.strdup(lip->get_tok_start() + skip, length), length);
   lip->m_cpp_text_start= lip->get_cpp_tok_start() + skip;
   lip->m_cpp_text_end= lip->m_cpp_text_start + tmp.size();
-
   return tmp;
 }
 
@@ -315,10 +313,10 @@
                                    uint32_t skip,
                                    uint32_t length, char quote)
 {
+  lip->yyUnget();                       // ptr points now after last token char
+  lip->yytoklen= length;
   lex_string_t tmp;
-  lip->yyUnget();                       // ptr points now after last token char
-  tmp.str=(char*) lip->m_session->mem.alloc(length + 1);
-  tmp.length= lip->yytoklen= length;
+  tmp.assign((char*)lip->m_session->mem.alloc(length + 1), length);
   const char* from= lip->get_tok_start() + skip;
   char* to= (char*)tmp.str;
   const char* end= to+length;
@@ -926,8 +924,8 @@
         return(ABORT_SYM);              // Illegal hex constant
       lip->yySkip();                    // Accept closing '
       length= lip->yyLength();          // Length of hexnum+3
-      if ((length % 2) == 0)
-        return(ABORT_SYM);              // odd number of hex digits
+      if (length % 2 == 0)
+        return ABORT_SYM;               // odd number of hex digits
       yylval->lex_str=get_token(lip,
                                 2,          // skip x'
                                 length-3);  // don't count x' and last '
@@ -997,10 +995,9 @@
         state= MY_LEX_CHAR;		// Read char by char
         break;
       }
-      yylval->lex_str.length= lip->yytoklen;
+      yylval->lex_str.assign(yylval->lex_str.data(), lip->yytoklen);
 
       lip->body_utf8_append(lip->m_cpp_text_start);
-
       lip->body_utf8_append_literal(&yylval->lex_str, lip->m_cpp_text_end);
 
       lex->text_string_is_7bit= (lip->tok_bitmap & 0x80) ? 0 : 1;

=== modified file 'drizzled/sql_table.cc'
--- drizzled/sql_table.cc	2011-10-10 17:33:19 +0000
+++ drizzled/sql_table.cc	2011-10-14 09:23:40 +0000
@@ -930,7 +930,7 @@
       return -1;
     }
 
-    key_info->comment.length= key->key_create_info.comment.size();
+    key_info->comment.assign(key_info->comment.data(), key->key_create_info.comment.size());
     if (key_info->comment.size() > 0)
     {
       key_info->flags|= HA_USES_COMMENT;

=== modified file 'drizzled/sql_yacc.yy'
--- drizzled/sql_yacc.yy	2011-10-10 17:33:19 +0000
+++ drizzled/sql_yacc.yy	2011-10-14 09:23:40 +0000
@@ -1840,8 +1840,14 @@
           default_collation_schema
           {
             Lex.name= $3;
-            if (Lex.name.str == NULL && Lex.session->copy_db_to(Lex.name.str, Lex.name.length))
-              DRIZZLE_YYABORT;
+            if (not Lex.name.data())
+            {
+              char* db;
+              size_t db_length;
+              if (Lex.session->copy_db_to(db, db_length))
+                DRIZZLE_YYABORT;
+              Lex.name.assign(db, db_length);
+            }
           }
         ;
 

=== modified file 'drizzled/statement/create_schema.cc'
--- drizzled/statement/create_schema.cc	2011-04-04 21:37:55 +0000
+++ drizzled/statement/create_schema.cc	2011-10-14 09:23:40 +0000
@@ -34,8 +34,7 @@
 
 using namespace std;
 
-namespace drizzled
-{
+namespace drizzled {
 
 bool statement::CreateSchema::execute()
 {
@@ -48,11 +47,11 @@
     return true;
   }
 
-  identifier::Schema schema_identifier(string(lex().name.str, lex().name.length));
+  identifier::Schema schema_identifier(to_string(lex().name));
   if (not check(schema_identifier))
     return false;
 
-  drizzled::message::schema::init(schema_message, lex().name.str);
+  drizzled::message::schema::init(schema_message, lex().name.data());
 
   message::set_definer(schema_message, *session().user());
 
@@ -117,4 +116,3 @@
 }
 
 } /* namespace drizzled */
-

=== modified file 'drizzled/statement/create_table.cc'
--- drizzled/statement/create_table.cc	2011-07-05 15:59:49 +0000
+++ drizzled/statement/create_table.cc	2011-10-14 09:23:40 +0000
@@ -32,9 +32,7 @@
 
 #include <iostream>
 
-namespace drizzled
-{
-
+namespace drizzled {
 namespace statement {
 
 CreateTable::CreateTable(Session *in_session, Table_ident *ident, bool is_temporary) :
@@ -49,19 +47,12 @@
   create_table_list(NULL)
 {
   set_command(SQLCOM_CREATE_TABLE);
-  createTableMessage().set_name(ident->table.str, ident->table.length);
+  createTableMessage().set_name(ident->table.data(), ident->table.size());
 #if 0
-  createTableMessage().set_schema(ident->db.str, ident->db.length);
+  createTableMessage().set_schema(ident->db.data(), ident->db.size());
 #endif
 
-  if (is_temporary)
-  {
-    createTableMessage().set_type(message::Table::TEMPORARY);
-  }
-  else
-  {
-    createTableMessage().set_type(message::Table::STANDARD);
-  }
+  createTableMessage().set_type(is_temporary ? message::Table::TEMPORARY : message::Table::STANDARD);
 }
 
 CreateTable::CreateTable(Session *in_session) :
@@ -338,4 +329,3 @@
 }
 
 } /* namespace drizzled */
-

=== modified file 'drizzled/statement/drop_schema.cc'
--- drizzled/statement/drop_schema.cc	2011-03-23 14:35:15 +0000
+++ drizzled/statement/drop_schema.cc	2011-10-14 09:23:40 +0000
@@ -31,8 +31,7 @@
 
 using namespace std;
 
-namespace drizzled
-{
+namespace drizzled {
 
 bool statement::DropSchema::execute()
 {
@@ -42,20 +41,17 @@
     return true;
   }
 
-  identifier::Schema schema_identifier(std::string(lex().name.str, lex().name.length));
+  identifier::Schema schema_identifier(to_string(lex().name));
 
   if (not schema::check(session(), schema_identifier))
   {
     my_error(ER_WRONG_DB_NAME, schema_identifier);
-
     return false;
   }
 
   if (session().inTransaction())
   {
-    my_message(ER_LOCK_OR_ACTIVE_TRANSACTION, 
-        ER(ER_LOCK_OR_ACTIVE_TRANSACTION), 
-        MYF(0));
+    my_message(ER_LOCK_OR_ACTIVE_TRANSACTION, ER(ER_LOCK_OR_ACTIVE_TRANSACTION), MYF(0));
     return true;
   }
   
@@ -80,4 +76,3 @@
 }
 
 } /* namespace drizzled */
-

=== modified file 'drizzled/table.cc'
--- drizzled/table.cc	2011-07-25 14:24:19 +0000
+++ drizzled/table.cc	2011-10-14 09:23:40 +0000
@@ -311,8 +311,7 @@
   if (!length || length > NAME_LEN || name[length - 1] == ' ')
     return 1;
   lex_string_t ident;
-  ident.str= (char*) name;
-  ident.length= length;
+  ident.assign(name, length);
   return check_identifier_name(&ident);
 }
 

=== modified file 'drizzled/util/data_ref.h'
--- drizzled/util/data_ref.h	2011-10-10 12:58:39 +0000
+++ drizzled/util/data_ref.h	2011-10-14 09:23:40 +0000
@@ -20,6 +20,7 @@
 #include <cstddef>
 #include <cstring>
 #include <ostream>
+#include <string>
 
 template <class T>
 class data_ref_basic
@@ -96,12 +97,6 @@
   {
     return begin() == end();
   }
-
-  friend std::ostream& operator<<(std::ostream& os, data_ref_basic<T> v)
-  {
-    os.write(v.data(), v.size());
-    return os;
-  }
 private:
   T begin_;
   T end_;
@@ -109,3 +104,14 @@
 
 typedef data_ref_basic<const unsigned char*> data_ref;
 typedef data_ref_basic<const char*> str_ref;
+
+inline std::ostream& operator<<(std::ostream& os, str_ref v)
+{
+  os.write(v.data(), v.size());
+  return os;
+}
+
+inline std::string to_string(str_ref v)
+{
+  return std::string(v.data(), v.size());
+}

